# x1

[![PyPI version](https://img.shields.io/pypi/v/xone.svg)](https://badge.fury.io/py/xone)
[![PyPI version](https://img.shields.io/pypi/pyversions/xone.svg)](https://badge.fury.io/py/xone)

[![Coffee](https://www.buymeacoffee.com/assets/img/custom_images/purple_img.png)](https://www.buymeacoffee.com/Lntx29Oof)

Frequently used functions for financial data analysis

## Installation

```cmd
pip install xone
```

|                |                                                                                                                                                 |
| -------------- | ----------------------------------------------------------------------------------------------------------------------------------------------- |
| Docs           | [![Documentation Status](https://readthedocs.org/projects/xone/badge/?version=latest)](https://xone.readthedocs.io/en/latest)                   |
| Build          | [![Actions Status](https://github.com/alpha-xone/xone/workflows/Auto%20CI/badge.svg)](https://github.com/alpha-xone/xone/actions)               |
| Coverage       | [![codecov](https://codecov.io/gh/alpha-xone/xone/branch/master/graph/badge.svg)](https://codecov.io/gh/alpha-xone/xone)                        |
| Quality        | [![Codacy Badge](https://api.codacy.com/project/badge/Grade/eb3d11949a1343d9aa4806a31f3fcc41)](https://www.codacy.com/app/alpha-xone/xone)      |
|                | [![CodeFactor](https://www.codefactor.io/repository/github/alpha-xone/xone/badge)](https://www.codefactor.io/repository/github/alpha-xone/xone) |
| License        | [![GitHub license](https://img.shields.io/github/license/alpha-xone/xone.svg)](https://github.com/alpha-xone/xone/blob/master/LICENSE)          |
